@@ -11,47 +11,71 @@ typedef Eo Efl_Canvas_Object;
 #ifndef _EFL_CANVAS_OBJECT_EO_TYPES
 #define _EFL_CANVAS_OBJECT_EO_TYPES
 
+/** EFL event animator tick data structure
+ *
+ * @since 1.22
+ *
+ * @ingroup Efl_Event_Animator_Tick
+ */
+typedef struct _Efl_Event_Animator_Tick
+{
+  Eina_Rect update_area; /**< Area of the canvas that will be pushed to screen.
+                          *
+                          * @since 1.22 */
+} Efl_Event_Animator_Tick;
+
 
 #endif
 /** Efl canvas object abstract class
+ *
+ * @since 1.22
  *
  * @ingroup Efl_Canvas_Object
  */
 #define EFL_CANVAS_OBJECT_CLASS efl_canvas_object_class_get()
 
-EWAPI const Efl_Class *efl_canvas_object_class_get(void);
+EWAPI const Efl_Class *efl_canvas_object_class_get(void) EINA_CONST;
 
+#ifdef EFL_BETA_API_SUPPORT
 /**
  * @brief Low-level pointer behaviour by device. See
  * @ref efl_canvas_object_pointer_mode_get and
  * @ref efl_canvas_object_pointer_mode_set for more explanation.
  *
+ * @param[in] obj The object.
  * @param[in] dev The pointer device to set/get the mode. Use @c null for the
  * default pointer.
  * @param[in] pointer_mode The pointer mode
  *
- * @since 1.19
+ * @return @c true if pointer mode was set, @c false otherwise
+ *
+ * @since 1.22
  *
  * @ingroup Efl_Canvas_Object
  */
-EOAPI Eina_Bool efl_canvas_object_pointer_mode_by_device_set(Eo *obj, Efl_Input_Device * dev, Efl_Input_Object_Pointer_Mode pointer_mode);
+EOAPI Eina_Bool efl_canvas_object_pointer_mode_by_device_set(Eo *obj, Efl_Input_Device *dev, Efl_Input_Object_Pointer_Mode pointer_mode);
+#endif /* EFL_BETA_API_SUPPORT */
 
+#ifdef EFL_BETA_API_SUPPORT
 /**
  * @brief Low-level pointer behaviour by device. See
  * @ref efl_canvas_object_pointer_mode_get and
  * @ref efl_canvas_object_pointer_mode_set for more explanation.
  *
+ * @param[in] obj The object.
  * @param[in] dev The pointer device to set/get the mode. Use @c null for the
  * default pointer.
  *
  * @return The pointer mode
  *
- * @since 1.19
+ * @since 1.22
  *
  * @ingroup Efl_Canvas_Object
  */
-EOAPI Efl_Input_Object_Pointer_Mode efl_canvas_object_pointer_mode_by_device_get(const Eo *obj, Efl_Input_Device * dev);
+EOAPI Efl_Input_Object_Pointer_Mode efl_canvas_object_pointer_mode_by_device_get(const Eo *obj, Efl_Input_Device *dev);
+#endif /* EFL_BETA_API_SUPPORT */
 
+#ifdef EFL_BETA_API_SUPPORT
 /**
  * @brief Low-level pointer behaviour.
  *
@@ -66,17 +90,23 @@ EOAPI Efl_Input_Object_Pointer_Mode efl_canvas_object_pointer_mode_by_device_get
  * If the value is @ref EFL_INPUT_OBJECT_POINTER_MODE_NO_GRAB, then events will
  * be emitted just when inside this object area.
  *
- * The default value is @ref EFL_INPUT_OBJECT_POINTER_MODE_AUTO_GRAB. See also:
- * @ref efl_canvas_object_pointer_mode_by_device_get and
+ * See also: @ref efl_canvas_object_pointer_mode_by_device_get and
  * @ref efl_canvas_object_pointer_mode_by_device_set Note: This function will
  * only set/get the mode for the default pointer.
  *
+ * @param[in] obj The object.
  * @param[in] pointer_mode Input pointer mode
  *
+ * @return @c true if pointer behaviour was set, @c false otherwise
+ *
+ * @since 1.22
+ *
  * @ingroup Efl_Canvas_Object
  */
 EOAPI Eina_Bool efl_canvas_object_pointer_mode_set(Eo *obj, Efl_Input_Object_Pointer_Mode pointer_mode);
+#endif /* EFL_BETA_API_SUPPORT */
 
+#ifdef EFL_BETA_API_SUPPORT
 /**
  * @brief Low-level pointer behaviour.
  *
@@ -91,48 +121,20 @@ EOAPI Eina_Bool efl_canvas_object_pointer_mode_set(Eo *obj, Efl_Input_Object_Poi
  * If the value is @ref EFL_INPUT_OBJECT_POINTER_MODE_NO_GRAB, then events will
  * be emitted just when inside this object area.
  *
- * The default value is @ref EFL_INPUT_OBJECT_POINTER_MODE_AUTO_GRAB. See also:
- * @ref efl_canvas_object_pointer_mode_by_device_get and
+ * See also: @ref efl_canvas_object_pointer_mode_by_device_get and
  * @ref efl_canvas_object_pointer_mode_by_device_set Note: This function will
  * only set/get the mode for the default pointer.
  *
+ * @param[in] obj The object.
+ *
  * @return Input pointer mode
  *
+ * @since 1.22
+ *
  * @ingroup Efl_Canvas_Object
  */
 EOAPI Efl_Input_Object_Pointer_Mode efl_canvas_object_pointer_mode_get(const Eo *obj);
-
-/**
- * @brief Read-only value indicating whether the main pointer is in the object.
- *
- * This shall be true between pointer,in and pointer,out events (coming in
- * matching numbers). Note that group objects may receive multiple pointer,in
- * in a row. See algo @ref efl_canvas_object_pointer_device_in_get
- *
- * @return If @c true the main pointer has entered this object.
- *
- * @since 1.19
- *
- * @ingroup Efl_Canvas_Object
- */
-EOAPI Eina_Bool efl_canvas_object_pointer_in_get(const Eo *obj);
-
-/**
- * @brief Read-only value indicating whether a pointer is in the object.
- *
- * This shall be true between pointer,in and pointer,out events (coming in
- * matching numbers). Note that group objects may receive multiple pointer,in
- * in a row.
- *
- * @param[in] pointer The pointer. Use @c null for the defaul pointer
- *
- * @return If @c true the pointer has entered this object.
- *
- * @since 1.19
- *
- * @ingroup Efl_Canvas_Object
- */
-EOAPI Eina_Bool efl_canvas_object_pointer_device_in_get(const Eo *obj, Efl_Input_Device * pointer);
+#endif /* EFL_BETA_API_SUPPORT */
 
 /**
  * @brief Render mode to be used for compositing the Evas object.
@@ -144,12 +146,15 @@ EOAPI Eina_Bool efl_canvas_object_pointer_device_in_get(const Eo *obj, Efl_Input
  *
  * Please do not assume that @ref EFL_GFX_RENDER_OP_COPY mode can be used to
  * "poke" holes in a window (to see through it), as only the compositor can
- * ensure that. Copy mode should only be used with otherwise opaque widgets, or
- * inside non-window surfaces (eg. a transparent background inside a buffer
+ * ensure that. Copy mode should only be used with otherwise opaque widgets or
+ * inside non-window surfaces (e.g. a transparent background inside a buffer
  * canvas).
  *
+ * @param[in] obj The object.
  * @param[in] render_op Blend or copy.
  *
+ * @since 1.22
+ *
  * @ingroup Efl_Canvas_Object
  */
 EOAPI void efl_canvas_object_render_op_set(Eo *obj, Efl_Gfx_Render_Op render_op);
@@ -164,54 +169,24 @@ EOAPI void efl_canvas_object_render_op_set(Eo *obj, Efl_Gfx_Render_Op render_op)
  *
  * Please do not assume that @ref EFL_GFX_RENDER_OP_COPY mode can be used to
  * "poke" holes in a window (to see through it), as only the compositor can
- * ensure that. Copy mode should only be used with otherwise opaque widgets, or
- * inside non-window surfaces (eg. a transparent background inside a buffer
+ * ensure that. Copy mode should only be used with otherwise opaque widgets or
+ * inside non-window surfaces (e.g. a transparent background inside a buffer
  * canvas).
  *
+ * @param[in] obj The object.
+ *
  * @return Blend or copy.
  *
+ * @since 1.22
+ *
  * @ingroup Efl_Canvas_Object
  */
 EOAPI Efl_Gfx_Render_Op efl_canvas_object_render_op_get(const Eo *obj);
 
-/**
- * @brief Set whether an Evas object is to freeze (discard) events.
- *
- * If @c freeze is @c true, it will make events on @c obj to be discarded.
- * Unlike @ref efl_canvas_object_pass_events_set, events will not be passed to
- * next lower object. This API can be used for blocking events while @c obj is
- * on transiting.
- *
- * If @c freeze is @c false, events will be processed on that object as normal.
- *
- * @warning If you block only key/mouse up events with this API, we won't
- * guarantee the state of the object, that only had key/mouse down events, will
- * be.
- *
- * @param[in] freeze Pass when @c obj is to freeze events ($true) or not
- * ($false).
- *
- * @since 1.1
- *
- * @ingroup Efl_Canvas_Object
- */
-EOAPI void efl_canvas_object_freeze_events_set(Eo *obj, Eina_Bool freeze);
-
-/**
- * @brief Determine whether an object is set to freeze (discard) events.
- *
- * @return Pass when @c obj is to freeze events ($true) or not ($false).
- *
- * @since 1.1
- *
- * @ingroup Efl_Canvas_Object
- */
-EOAPI Eina_Bool efl_canvas_object_freeze_events_get(const Eo *obj);
-
 /**
  * @brief Clip one object to another.
  *
- * This function will clip the object @c obj to the area occupied by the object
+ * This property will clip the object @c obj to the area occupied by the object
  * @c clip. This means the object @c obj will only be visible within the area
  * occupied by the clipping object ($clip).
  *
@@ -230,8 +205,9 @@ EOAPI Eina_Bool efl_canvas_object_freeze_events_get(const Eo *obj);
  * it, it will become visible again.
  *
  * The visibility of an object affects the objects that are clipped by it, so
- * if the object clipping others is not shown (as in @ref evas_object_show),
- * the objects clipped by it will not be shown  either.
+ * if the object clipping others is not shown (as in
+ * @ref efl_gfx_entity_visible_get), the objects clipped by it will not be
+ * shown  either.
  *
  * If @c obj was being clipped by another object when this function is  called,
  * it gets implicitly removed from the old clipper's domain and is made now to
@@ -244,77 +220,141 @@ EOAPI Eina_Bool efl_canvas_object_freeze_events_get(const Eo *obj);
  * @note Only rectangle and image (masks) objects can be used as clippers.
  * Anything else will result in undefined behaviour.
  *
- * @param[in] clip The object to clip @c obj by.
+ * @param[in] obj The object.
+ * @param[in] clipper The object to clip @c obj by.
+ *
+ * @since 1.22
  *
  * @ingroup Efl_Canvas_Object
  */
-EOAPI void efl_canvas_object_clip_set(Eo *obj, Efl_Canvas_Object *clip) EINA_ARG_NONNULL(2);
+EOAPI void efl_canvas_object_clipper_set(Eo *obj, Efl_Canvas_Object *clipper);
 
 /**
- * @brief Get the object clipping @c obj (if any).
+ * @brief Clip one object to another.
  *
- * This function returns the object clipping @c obj. If @c obj is not being
- * clipped at all, @c null is returned. The object @c obj must be a valid
- * Evas_Object.
+ * This property will clip the object @c obj to the area occupied by the object
+ * @c clip. This means the object @c obj will only be visible within the area
+ * occupied by the clipping object ($clip).
+ *
+ * The color of the object being clipped will be multiplied by the color of the
+ * clipping one, so the resulting color for the former will be "RESULT = (OBJ *
+ * CLIP) / (255 * 255)", per color element (red, green, blue and alpha).
+ *
+ * Clipping is recursive, so clipping objects may be clipped by others, and
+ * their color will in term be multiplied. You may not set up circular clipping
+ * lists (i.e. object 1 clips object 2, which clips object 1): the behavior of
+ * Evas is undefined in this case.
+ *
+ * Objects which do not clip others are visible in the canvas as normal; those
+ * that clip one or more objects become invisible themselves, only affecting
+ * what they clip. If an object ceases to have other objects being clipped by
+ * it, it will become visible again.
+ *
+ * The visibility of an object affects the objects that are clipped by it, so
+ * if the object clipping others is not shown (as in
+ * @ref efl_gfx_entity_visible_get), the objects clipped by it will not be
+ * shown  either.
+ *
+ * If @c obj was being clipped by another object when this function is  called,
+ * it gets implicitly removed from the old clipper's domain and is made now to
+ * be clipped by its new clipper.
+ *
+ * If @c clip is @c null, this call will disable clipping for the object i.e.
+ * its visibility and color get detached from the previous clipper. If it
+ * wasn't, this has no effect.
+ *
+ * @note Only rectangle and image (masks) objects can be used as clippers.
+ * Anything else will result in undefined behaviour.
+ *
+ * @param[in] obj The object.
  *
  * @return The object to clip @c obj by.
  *
+ * @since 1.22
+ *
  * @ingroup Efl_Canvas_Object
  */
-EOAPI Efl_Canvas_Object *efl_canvas_object_clip_get(const Eo *obj);
+EOAPI Efl_Canvas_Object *efl_canvas_object_clipper_get(const Eo *obj);
+
+#ifdef EFL_BETA_API_SUPPORT
+/**
+ * @brief A hint for an object that its size will not change.
+ *
+ * When this flag is set, various optimizations may be employed by the renderer
+ * based on the fixed size of the object.
+ *
+ * It is a user error to change the size of an object while this flag is set.
+ *
+ * @param[in] obj The object.
+ * @param[in] enable Whether the object size is known to be static.
+ *
+ * @since 1.23
+ *
+ * @ingroup Efl_Canvas_Object
+ */
+EOAPI void efl_canvas_object_has_fixed_size_set(Eo *obj, Eina_Bool enable);
+#endif /* EFL_BETA_API_SUPPORT */
+
+#ifdef EFL_BETA_API_SUPPORT
+/**
+ * @brief A hint for an object that its size will not change.
+ *
+ * When this flag is set, various optimizations may be employed by the renderer
+ * based on the fixed size of the object.
+ *
+ * It is a user error to change the size of an object while this flag is set.
+ *
+ * @param[in] obj The object.
+ *
+ * @return Whether the object size is known to be static.
+ *
+ * @since 1.23
+ *
+ * @ingroup Efl_Canvas_Object
+ */
+EOAPI Eina_Bool efl_canvas_object_has_fixed_size_get(const Eo *obj);
+#endif /* EFL_BETA_API_SUPPORT */
 
 /**
- * @brief Set whether an Evas object is to repeat events.
+ * @brief Whether an Evas object is to repeat events to objects below it.
  *
  * If @c repeat is @c true, it will make events on @c obj to also be repeated
- * for the next lower object in the objects' stack (see see @ref
- * evas_object_below_get).
+ * for the next lower object in the objects' stack (see see
+ * @ref efl_gfx_stack_below_get).
  *
  * If @c repeat is @c false, events occurring on @c obj will be processed only
  * on it.
  *
+ * @param[in] obj The object.
  * @param[in] repeat Whether @c obj is to repeat events ($true) or not
  * ($false).
  *
+ * @since 1.22
+ *
  * @ingroup Efl_Canvas_Object
  */
 EOAPI void efl_canvas_object_repeat_events_set(Eo *obj, Eina_Bool repeat);
 
 /**
- * @brief Determine whether an object is set to repeat events.
+ * @brief Whether an Evas object is to repeat events to objects below it.
+ *
+ * If @c repeat is @c true, it will make events on @c obj to also be repeated
+ * for the next lower object in the objects' stack (see see
+ * @ref efl_gfx_stack_below_get).
+ *
+ * If @c repeat is @c false, events occurring on @c obj will be processed only
+ * on it.
+ *
+ * @param[in] obj The object.
  *
  * @return Whether @c obj is to repeat events ($true) or not ($false).
  *
+ * @since 1.22
+ *
  * @ingroup Efl_Canvas_Object
  */
 EOAPI Eina_Bool efl_canvas_object_repeat_events_get(const Eo *obj);
 
-/**
- * @brief Sets the scaling factor for an Evas object. Does not affect all
- * objects.
- *
- * This will multiply the object's dimension by the given factor, thus altering
- * its geometry (width and height). Useful when you want scalable UI elements,
- * possibly at run time.
- *
- * @note Only text and textblock objects have scaling change handlers. Other
- * objects won't change visually on this call.
- *
- * @param[in] scale The scaling factor. 1.0 means no scaling, default size.
- *
- * @ingroup Efl_Canvas_Object
- */
-EOAPI void efl_canvas_object_scale_set(Eo *obj, double scale);
-
-/**
- * @brief Retrieves the scaling factor for the given Evas object.
- *
- * @return The scaling factor. 1.0 means no scaling, default size.
- *
- * @ingroup Efl_Canvas_Object
- */
-EOAPI double efl_canvas_object_scale_get(const Eo *obj);
-
 /**
  * @brief Indicates that this object is the keyboard event receiver on its
  * canvas.
@@ -327,8 +367,11 @@ EOAPI double efl_canvas_object_scale_get(const Eo *obj);
  * @ref efl_canvas_object_seat_focus_add,
  * @ref efl_canvas_object_seat_focus_del.
  *
+ * @param[in] obj The object.
  * @param[in] focus @c true when set as focused or @c false otherwise.
  *
+ * @since 1.22
+ *
  * @ingroup Efl_Canvas_Object
  */
 EOAPI void efl_canvas_object_key_focus_set(Eo *obj, Eina_Bool focus);
@@ -345,8 +388,12 @@ EOAPI void efl_canvas_object_key_focus_set(Eo *obj, Eina_Bool focus);
  * @ref efl_canvas_object_seat_focus_add,
  * @ref efl_canvas_object_seat_focus_del.
  *
+ * @param[in] obj The object.
+ *
  * @return @c true when set as focused or @c false otherwise.
  *
+ * @since 1.22
+ *
  * @ingroup Efl_Canvas_Object
  */
 EOAPI Eina_Bool efl_canvas_object_key_focus_get(const Eo *obj);
@@ -354,229 +401,238 @@ EOAPI Eina_Bool efl_canvas_object_key_focus_get(const Eo *obj);
 /**
  * @brief Check if this object is focused.
  *
+ * @param[in] obj The object.
+ *
  * @return @c true if focused by at least one seat or @c false otherwise.
  *
- * @since 1.19
+ * @since 1.22
  *
  * @ingroup Efl_Canvas_Object
  */
 EOAPI Eina_Bool efl_canvas_object_seat_focus_get(const Eo *obj);
 
+#ifdef EFL_BETA_API_SUPPORT
 /**
  * @brief Check if this object is focused by a given seat
  *
+ * @param[in] obj The object.
  * @param[in] seat The seat to check if the object is focused. Use @c null for
  * the default seat.
  *
  * @return @c true if focused or @c false otherwise.
  *
- * @since 1.19
+ * @since 1.22
  *
  * @ingroup Efl_Canvas_Object
  */
 EOAPI Eina_Bool efl_canvas_object_seat_focus_check(Eo *obj, Efl_Input_Device *seat);
+#endif /* EFL_BETA_API_SUPPORT */
 
+#ifdef EFL_BETA_API_SUPPORT
 /**
  * @brief Add a seat to the focus list.
  *
- * Evas supports that an Efl.Canvas.Object may be focused by multiple seats at
- * the same time. This function adds a new seat to the focus list, in other
- * words, after the seat is added to the list this object will now be also
- * focused by this new seat.
+ * Evas allows the Efl.Canvas.Object to be focused by multiple seats at the
+ * same time. This function adds a new seat to the focus list. In other words,
+ * after the seat is added to the list this object will now be also focused by
+ * this new seat.
  *
- * This function generates an @ref EFL_CANVAS_OBJECT_EVENT_FOCUS_DEVICE_IN
- * event.
- *
- * @note The old focus APIs ( @ref evas_object_focus_get, @ref
- * evas_object_focus_set, @ref efl_canvas_object_key_grab) will still work,
- * however they will only act on the default seat.
+ * @note The old focus APIs still work, however they will only act on the
+ * default seat.
  *
+ * @param[in] obj The object.
  * @param[in] seat The seat that should be added to the focus list. Use @c null
  * for the default seat.
  *
  * @return @c true if the focus has been set or @c false otherwise.
  *
- * @since 1.19
+ * @since 1.22
  *
  * @ingroup Efl_Canvas_Object
  */
 EOAPI Eina_Bool efl_canvas_object_seat_focus_add(Eo *obj, Efl_Input_Device *seat);
+#endif /* EFL_BETA_API_SUPPORT */
 
+#ifdef EFL_BETA_API_SUPPORT
 /**
  * @brief Remove a seat from the focus list.
  *
- * Removing an seat from the focus list is an unfocus operation, thus it will
- * generate an @ref EFL_CANVAS_OBJECT_EVENT_FOCUS_DEVICE_OUT event.
- *
+ * @param[in] obj The object.
  * @param[in] seat The seat that should be removed from the focus list. Use
  * @c null for the default seat.
  *
  * @return @c true if the seat was removed from the focus list or @c false
  * otherwise.
  *
- * @since 1.19
+ * @since 1.22
  *
  * @ingroup Efl_Canvas_Object
  */
 EOAPI Eina_Bool efl_canvas_object_seat_focus_del(Eo *obj, Efl_Input_Device *seat);
+#endif /* EFL_BETA_API_SUPPORT */
 
 /**
- * @brief If @c true the object belongs to the window border decorations.
+ * @brief Whether to use precise (usually expensive) point collision detection
+ * for a given Evas object.
  *
- * This will be @c false by default, and should be @c false for all objects
- * created by the application, unless swallowed in some very specific parts of
- * the window.
- *
- * It is very unlikely that an application needs to call this manually, as the
- * window will handle this feature automatically.
- *
- * @param[in] is_frame @c true if the object is a frame, @c false otherwise
- *
- * @since 1.2
- *
- * @ingroup Efl_Canvas_Object
- */
-EOAPI void efl_canvas_object_is_frame_object_set(Eo *obj, Eina_Bool is_frame);
-
-/**
- * @brief If @c true the object belongs to the window border decorations.
- *
- * This will be @c false by default, and should be @c false for all objects
- * created by the application, unless swallowed in some very specific parts of
- * the window.
- *
- * It is very unlikely that an application needs to call this manually, as the
- * window will handle this feature automatically.
- *
- * @return @c true if the object is a frame, @c false otherwise
- *
- * @since 1.2
- *
- * @ingroup Efl_Canvas_Object
- */
-EOAPI Eina_Bool efl_canvas_object_is_frame_object_get(const Eo *obj);
-
-/**
- * @brief Set whether to use precise (usually expensive) point collision
- * detection for a given Evas object.
- *
- * Use this function to make Evas treat objects' transparent areas as not
+ * Use this property to make Evas treat objects' transparent areas as not
  * belonging to it with regard to mouse pointer events. By default, all of the
  * object's boundary rectangle will be taken in account for them.
  *
  * @warning By using precise point collision detection you'll be making Evas
  * more resource intensive.
  *
- * @param[in] precise Whether to use precise point collision detection or not.
- * The default value is false.
+ * @param[in] obj The object.
+ * @param[in] precise Whether to use precise point collision detection.
+ *
+ * @since 1.22
  *
  * @ingroup Efl_Canvas_Object
  */
 EOAPI void efl_canvas_object_precise_is_inside_set(Eo *obj, Eina_Bool precise);
 
 /**
- * @brief Determine whether an object is set to use precise point collision
- * detection.
+ * @brief Whether to use precise (usually expensive) point collision detection
+ * for a given Evas object.
  *
- * @return Whether to use precise point collision detection or not. The default
- * value is false.
+ * Use this property to make Evas treat objects' transparent areas as not
+ * belonging to it with regard to mouse pointer events. By default, all of the
+ * object's boundary rectangle will be taken in account for them.
+ *
+ * @warning By using precise point collision detection you'll be making Evas
+ * more resource intensive.
+ *
+ * @param[in] obj The object.
+ *
+ * @return Whether to use precise point collision detection.
+ *
+ * @since 1.22
  *
  * @ingroup Efl_Canvas_Object
  */
 EOAPI Eina_Bool efl_canvas_object_precise_is_inside_get(const Eo *obj);
 
 /**
- * @brief Set whether events on a smart object's member should get propagated
- * up to its parent.
+ * @brief Whether events on a smart object's member should be propagated up to
+ * its parent.
  *
  * This function has no effect if @c obj is not a member of a smart object.
  *
  * If @c prop is @c true, events occurring on this object will be propagated on
  * to the smart object of which @c obj is a member. If @c prop is @c false,
  * events occurring on this object will not be propagated on to the smart
- * object of which @c obj is a member. The default value is @c true.
+ * object of which @c obj is a member.
  *
  * See also @ref efl_canvas_object_repeat_events_set,
- * @ref efl_canvas_object_pass_events_set,
- * @ref efl_canvas_object_freeze_events_set.
+ * @ref efl_canvas_object_pass_events_set.
  *
- * @param[in] propagate Whether to propagate events ($true) or not ($false).
+ * @param[in] obj The object.
+ * @param[in] propagate Whether to propagate events.
+ *
+ * @since 1.22
  *
  * @ingroup Efl_Canvas_Object
  */
 EOAPI void efl_canvas_object_propagate_events_set(Eo *obj, Eina_Bool propagate);
 
 /**
- * @brief Retrieve whether an Evas object is set to propagate events.
+ * @brief Whether events on a smart object's member should be propagated up to
+ * its parent.
  *
- * See also @ref efl_canvas_object_repeat_events_get,
- * @ref efl_canvas_object_pass_events_get,
- * @ref efl_canvas_object_freeze_events_get.
+ * This function has no effect if @c obj is not a member of a smart object.
  *
- * @return Whether to propagate events ($true) or not ($false).
+ * If @c prop is @c true, events occurring on this object will be propagated on
+ * to the smart object of which @c obj is a member. If @c prop is @c false,
+ * events occurring on this object will not be propagated on to the smart
+ * object of which @c obj is a member.
+ *
+ * See also @ref efl_canvas_object_repeat_events_set,
+ * @ref efl_canvas_object_pass_events_set.
+ *
+ * @param[in] obj The object.
+ *
+ * @return Whether to propagate events.
+ *
+ * @since 1.22
  *
  * @ingroup Efl_Canvas_Object
  */
 EOAPI Eina_Bool efl_canvas_object_propagate_events_get(const Eo *obj);
 
 /**
- * @brief Set whether an Evas object is to pass (ignore) events.
+ * @brief Whether an Evas object is to pass (ignore) events.
  *
  * If @c pass is @c true, it will make events on @c obj to be ignored. They
  * will be triggered on the next lower object (that is not set to pass events),
- * instead (see @ref evas_object_below_get).
+ * instead (see @ref efl_gfx_stack_below_get).
  *
- * If @c pass is @c false, events will be processed on that object as normal.
+ * If @c pass is @c false events will be processed on that object as normal.
  *
  * See also @ref efl_canvas_object_repeat_events_set,
- * @ref efl_canvas_object_propagate_events_set,
- * @ref efl_canvas_object_freeze_events_set.
+ * @ref efl_canvas_object_propagate_events_set
  *
+ * @param[in] obj The object.
  * @param[in] pass Whether @c obj is to pass events ($true) or not ($false).
  *
+ * @since 1.22
+ *
  * @ingroup Efl_Canvas_Object
  */
 EOAPI void efl_canvas_object_pass_events_set(Eo *obj, Eina_Bool pass);
 
 /**
- * @brief Determine whether an object is set to pass (ignore) events.
+ * @brief Whether an Evas object is to pass (ignore) events.
  *
- * See also @ref efl_canvas_object_repeat_events_get,
- * @ref efl_canvas_object_propagate_events_get,
- * @ref efl_canvas_object_freeze_events_get.
+ * If @c pass is @c true, it will make events on @c obj to be ignored. They
+ * will be triggered on the next lower object (that is not set to pass events),
+ * instead (see @ref efl_gfx_stack_below_get).
+ *
+ * If @c pass is @c false events will be processed on that object as normal.
+ *
+ * See also @ref efl_canvas_object_repeat_events_set,
+ * @ref efl_canvas_object_propagate_events_set
+ *
+ * @param[in] obj The object.
  *
  * @return Whether @c obj is to pass events ($true) or not ($false).
  *
+ * @since 1.22
+ *
  * @ingroup Efl_Canvas_Object
  */
 EOAPI Eina_Bool efl_canvas_object_pass_events_get(const Eo *obj);
 
 /**
- * @brief Sets whether or not the given Evas object is to be drawn
- * anti-aliased.
+ * @brief Whether or not the given Evas object is to be drawn anti-aliased.
  *
+ * @param[in] obj The object.
  * @param[in] anti_alias @c true if the object is to be anti_aliased, @c false
  * otherwise.
  *
+ * @since 1.22
+ *
  * @ingroup Efl_Canvas_Object
  */
 EOAPI void efl_canvas_object_anti_alias_set(Eo *obj, Eina_Bool anti_alias);
 
 /**
- * @brief Retrieves whether or not the given Evas object is to be drawn
- * anti_aliased.
+ * @brief Whether or not the given Evas object is to be drawn anti-aliased.
+ *
+ * @param[in] obj The object.
  *
  * @return @c true if the object is to be anti_aliased, @c false otherwise.
  *
+ * @since 1.22
+ *
  * @ingroup Efl_Canvas_Object
  */
 EOAPI Eina_Bool efl_canvas_object_anti_alias_get(const Eo *obj);
 
 /**
- * @brief Return a list of objects currently clipped by @c obj.
+ * @brief List of objects currently clipped by @c obj.
  *
- * This returns the internal list handle that contains all objects clipped by
- * the object @c obj. If none are clipped by it, the call returns @c null. This
+ * This returns the internal list handle containing all objects clipped by the
+ * object @c obj. If none are clipped by it, the call returns @c null. This
  * list is only valid until the clip list is changed and should be fetched
  * again with another call to this function if any objects being clipped by
  * this object are unclipped, clipped by a new object, deleted or get the
@@ -584,13 +640,17 @@ EOAPI Eina_Bool efl_canvas_object_anti_alias_get(const Eo *obj);
  * should not be used anymore after that point. Any use of the list after this
  * may have undefined results, possibly leading to crashes.
  *
- * See also @ref efl_canvas_object_clip_get.
+ * See also @ref efl_canvas_object_clipper_get.
+ *
+ * @param[in] obj The object.
  *
  * @return An iterator over the list of objects clipped by @c obj.
  *
+ * @since 1.22
+ *
  * @ingroup Efl_Canvas_Object
  */
-EOAPI Eina_Iterator *efl_canvas_object_clipees_get(const Eo *obj) EINA_WARN_UNUSED_RESULT;
+EOAPI Eina_Iterator *efl_canvas_object_clipped_objects_get(const Eo *obj) EFL_TRANSFER_OWNERSHIP EINA_WARN_UNUSED_RESULT;
 
 #ifdef EFL_CANVAS_OBJECT_PROTECTED
 /**
@@ -600,9 +660,11 @@ EOAPI Eina_Iterator *efl_canvas_object_clipees_get(const Eo *obj) EINA_WARN_UNUS
  * internally for rendering and the normal parent is what the user expects to
  * be the parent.
  *
+ * @param[in] obj The object.
+ *
  * @return The parent smart object of @c obj or @c null.
  *
- * @since 1.18
+ * @since 1.22
  *
  * @ingroup Efl_Canvas_Object
  */
@@ -615,8 +677,11 @@ EOAPI Efl_Canvas_Object *efl_canvas_object_render_parent_get(const Eo *obj);
  * inherit the paragraph direction from the given object. The default paragraph
  * direction is @c inherit.
  *
+ * @param[in] obj The object.
  * @param[in] dir Paragraph direction for the given object.
  *
+ * @since 1.22
+ *
  * @ingroup Efl_Canvas_Object
  */
 EOAPI void efl_canvas_object_paragraph_direction_set(Eo *obj, Efl_Text_Bidirectional_Type dir);
@@ -627,22 +692,28 @@ EOAPI void efl_canvas_object_paragraph_direction_set(Eo *obj, Efl_Text_Bidirecti
  * inherit the paragraph direction from the given object. The default paragraph
  * direction is @c inherit.
  *
+ * @param[in] obj The object.
+ *
  * @return Paragraph direction for the given object.
  *
+ * @since 1.22
+ *
  * @ingroup Efl_Canvas_Object
  */
 EOAPI Efl_Text_Bidirectional_Type efl_canvas_object_paragraph_direction_get(const Eo *obj);
 
 /**
- * @brief Test if any object is clipped by @c obj.
+ * @brief Returns the number of objects clipped by @c obj
  *
- * @return @c true if any object is clipped by @c obj, @c false otherwise
+ * @param[in] obj The object.
  *
- * @since 1.8
+ * @return The number of objects clipped by @c obj
+ *
+ * @since 1.22
  *
  * @ingroup Efl_Canvas_Object
  */
-EOAPI Eina_Bool efl_canvas_object_clipees_has(const Eo *obj) EINA_WARN_UNUSED_RESULT;
+EOAPI unsigned int efl_canvas_object_clipped_objects_count(const Eo *obj) EINA_WARN_UNUSED_RESULT;
 
 /**
  * @brief Requests @c keyname key events be directed to @c obj.
@@ -651,38 +722,34 @@ EOAPI Eina_Bool efl_canvas_object_clipees_has(const Eo *obj) EINA_WARN_UNUSED_RE
  * strokes even if other objects have focus. Whenever a key is grabbed, only
  * the objects grabbing it will get the events for the given keys.
  *
- * @c keyname is a platform dependent symbolic name for the key pressed (see
- * @ref Evas_Keys for more information).
+ * @c keyname is a platform dependent symbolic name for the key pressed.
  *
  * @c modifiers and @c not_modifiers are bit masks of all the modifiers that
  * must and mustn't, respectively, be pressed along with @c keyname key in
  * order to trigger this new key grab. Modifiers can be things such as Shift
  * and Ctrl as well as user defined types via @ref evas_key_modifier_add.
- * Retrieve them with @ref evas_key_modifier_mask_get or use 0 for empty masks.
- *
  * @c exclusive will make the given object the only one permitted to grab the
  * given key. If given @c true, subsequent calls on this function with
  * different @c obj arguments will fail, unless the key is ungrabbed again.
  *
  * @warning Providing impossible modifier sets creates undefined behavior.
  *
- * See also @ref efl_canvas_object_key_ungrab,
- * @ref efl_canvas_object_key_focus_get, @ref efl_canvas_object_key_focus_set,
- * @ref evas_focus_get, @ref evas_key_modifier_add.
- *
+ * @param[in] obj The object.
  * @param[in] keyname The key to request events for.
- * @param[in] modifiers A combinaison of modifier keys that must be present to
+ * @param[in] modifiers A combination of modifier keys that must be present to
  * trigger the event.
- * @param[in] not_modifiers A combinaison of modifier keys that must not be
+ * @param[in] not_modifiers A combination of modifier keys that must not be
  * present to trigger the event.
  * @param[in] exclusive Request that the @c obj is the only object receiving
  * the @c keyname events.
  *
  * @return @c true if the call succeeded, @c false otherwise.
  *
+ * @since 1.22
+ *
  * @ingroup Efl_Canvas_Object
  */
-EOAPI Eina_Bool efl_canvas_object_key_grab(Eo *obj, const char *keyname, Efl_Input_Modifier modifiers, Efl_Input_Modifier not_modifiers, Eina_Bool exclusive) EINA_WARN_UNUSED_RESULT EINA_ARG_NONNULL(2);
+EOAPI Eina_Bool efl_canvas_object_key_grab(Eo *obj, const char *keyname, Efl_Input_Modifier modifiers, Efl_Input_Modifier not_modifiers, Eina_Bool exclusive) EINA_WARN_UNUSED_RESULT;
 
 /**
  * @brief Removes the grab on @c keyname key events by @c obj.
@@ -694,21 +761,24 @@ EOAPI Eina_Bool efl_canvas_object_key_grab(Eo *obj, const char *keyname, Efl_Inp
  * @ref efl_canvas_object_key_focus_get, @ref efl_canvas_object_key_focus_set,
  * and the legacy API evas_focus_get.
  *
+ * @param[in] obj The object.
  * @param[in] keyname The key the grab is set for.
  * @param[in] modifiers A mask of modifiers that must be present to trigger the
  * event.
  * @param[in] not_modifiers A mask of modifiers that must not not be present to
  * trigger the event.
  *
+ * @since 1.22
+ *
  * @ingroup Efl_Canvas_Object
  */
-EOAPI void efl_canvas_object_key_ungrab(Eo *obj, const char *keyname, Efl_Input_Modifier modifiers, Efl_Input_Modifier not_modifiers) EINA_ARG_NONNULL(2);
+EOAPI void efl_canvas_object_key_ungrab(Eo *obj, const char *keyname, Efl_Input_Modifier modifiers, Efl_Input_Modifier not_modifiers);
 
 /**
- * @brief Disable all rendering on the canvas.
+ * @brief Disables all rendering on the canvas.
  *
  * This flag will be used to indicate to Evas that this object should never be
- * rendered on the canvas under any circurmstances. In particular, this is
+ * rendered on the canvas under any circumstances. In particular, this is
  * useful to avoid drawing clipper objects (or masks) even when they don't clip
  * any object. This can also be used to replace the old source_visible flag
  * with proxy objects.
@@ -719,81 +789,68 @@ EOAPI void efl_canvas_object_key_ungrab(Eo *obj, const char *keyname, Efl_Input_
  * completely disappear from the canvas, and hide their clippees or be
  * invisible when used as proxy sources.
  *
+ * @param[in] obj The object.
  * @param[in] enable Enable "no-render" mode.
  *
- * @since 1.15
+ * @since 1.22
  *
  * @ingroup Efl_Canvas_Object
  */
 EOAPI void efl_canvas_object_no_render_set(Eo *obj, Eina_Bool enable);
 
 /**
- * @brief Returns the state of the "no-render" flag, which means, when true,
- * that an object should never be rendered on the canvas.
+ * @brief Disables all rendering on the canvas.
  *
- * This flag can be used to avoid rendering visible clippers on the canvas,
- * even if they currently don't clip any object.
+ * This flag will be used to indicate to Evas that this object should never be
+ * rendered on the canvas under any circumstances. In particular, this is
+ * useful to avoid drawing clipper objects (or masks) even when they don't clip
+ * any object. This can also be used to replace the old source_visible flag
+ * with proxy objects.
+ *
+ * This is different to the visible property, as even visible objects marked as
+ * "no-render" will never appear on screen. But those objects can still be used
+ * as proxy sources or clippers. When hidden, all "no-render" objects will
+ * completely disappear from the canvas, and hide their clippees or be
+ * invisible when used as proxy sources.
+ *
+ * @param[in] obj The object.
  *
  * @return Enable "no-render" mode.
  *
- * @since 1.15
+ * @since 1.22
  *
  * @ingroup Efl_Canvas_Object
  */
 EOAPI Eina_Bool efl_canvas_object_no_render_get(const Eo *obj);
 
 /**
- * @brief Returns whether the mouse pointer is logically inside the object.
+ * @brief Whether the coordinates are logically inside the object.
  *
- * @param[in] dev The pointer device.
+ * A value of @c true indicates the position is logically inside the object,
+ * and @c false implies it is logically outside the object.
  *
- * @return @c true if the pointer is inside, @c false otherwise.
+ * If @c obj is not a valid object, the return value is undefined.
  *
- * @since 1.20
+ * @param[in] obj The object.
+ * @param[in] pos The coordinates in pixels.
+ *
+ * @return @c true if the coordinates are inside the object, @c false otherwise
+ *
+ * @since 1.22
  *
  * @ingroup Efl_Canvas_Object
  */
-EOAPI Eina_Bool efl_canvas_object_pointer_inside_by_device_get(const Eo *obj, Efl_Input_Device * dev);
+EOAPI Eina_Bool efl_canvas_object_coords_inside_get(const Eo *obj, Eina_Position2D pos);
 
-/**
- * @brief Returns whether the default mouse pointer is logically inside the
- * object.
- *
- * When this function is called it will return a value of either @c false or
- * @c true, depending on if event_feed_mouse_in or event_feed_mouse_out have
- * been called to feed in a mouse enter event into the object.
- *
- * A return value of @c true indicates the mouse is logically inside the
- * object, and @c false implies it is logically outside the object.
- *
- * If @c e is not a valid object, the return value is undefined.
- *
- * @return @c true if the mouse pointer is inside the object, @c false
- * otherwise
- *
- * @ingroup Efl_Canvas_Object
- */
-EOAPI Eina_Bool efl_canvas_object_pointer_inside_get(const Eo *obj) EINA_WARN_UNUSED_RESULT;
+EWAPI extern const Efl_Event_Description _EFL_CANVAS_OBJECT_EVENT_ANIMATOR_TICK;
 
-/**
- * @brief Returns whether the coords are logically inside the object.
+/** Animator tick synchronized with screen vsync if possible.
+ * @return Efl_Event_Animator_Tick
  *
- * When this function is called it will return a value of either @c false or
- * @c true, depending on if the coords are inside the object's current
- * geometry.
- *
- * A return value of @c true indicates the position is logically inside the
- * object, and @c false implies it is logically outside the object.
- *
- * If @c e is not a valid object, the return value is undefined.
- *
- * @param[in] x The canvas-relative x coordinate.
- * @param[in] y The canvas-relative y coordinate.
- *
- * @return @c true if the coords are inside the object, @c false otherwise
+ * @since 1.22
  *
  * @ingroup Efl_Canvas_Object
  */
-EOAPI Eina_Bool efl_canvas_object_pointer_coords_inside_get(Eo *obj, int x, int y) EINA_WARN_UNUSED_RESULT;
+#define EFL_CANVAS_OBJECT_EVENT_ANIMATOR_TICK (&(_EFL_CANVAS_OBJECT_EVENT_ANIMATOR_TICK))
 
 #endif
